@@ -4,8 +4,11 @@ if(getRversion() >= "2.15.1") utils::globalVariables(c("ypos", "wb", "ia", "mw",
 
 #' @title Plot grouped or stacked frequencies
 #' @name sjp.grpfrq
-#' @references \url{http://strengejacke.wordpress.com/sjplot-r-package/} \cr \cr
-#'             \url{http://strengejacke.wordpress.com/2013/03/05/easily-plotting-grouped-bars-with-ggplot}
+#' @references \itemize{
+#'              \item \url{http://strengejacke.wordpress.com/sjplot-r-package/} \cr \cr
+#'              \item \url{http://strengejacke.wordpress.com/2013/03/05/easily-plotting-grouped-bars-with-ggplot}
+#'              }
+#'             
 #' @description Plot grouped or stacked frequencies of variables 
 #'                as bar/dor graphs, box or violin plots, histograms etc.
 #'                using ggplot. 
@@ -27,12 +30,15 @@ if(getRversion() >= "2.15.1") utils::globalVariables(c("ypos", "wb", "ia", "mw",
 #'          If \code{type} is \code{"histogram"}, you can use either \code{"dodge"} (default value), which displays the bars side-by-side,
 #'          or \code{"identity"}, which results in overlaying bars. In the latter case, it's recommended to adjust the 
 #'          \code{barAlpha} value.
-#' @param type The plot type. May be either \code{"b"}, \code{"bar"}, \code{"bars"} (default) for bar charts,
-#'          \code{"l"}, \code{"line"}, \code{"lines"} for line diagram,
-#'          \code{"d"}, \code{"dot"}, \code{"dots"} for dot plots,
-#'          \code{"h"}, \code{"hist"}, \code{"histogram"} for grouped histograms, 
-#'          \code{"box"}, \code{"boxplot"}, \code{"boxplots"} for box plots
-#'          or \code{"v"}, \code{"violin"} for violin box plots
+#' @param type The plot type. May be one of the following:
+#'          \itemize{
+#'            \item \code{"b"}, \code{"bar"}, \code{"bars"} (default) for bar charts
+#'            \item \code{"l"}, \code{"line"}, \code{"lines"} for line diagram
+#'            \item \code{"d"}, \code{"dot"}, \code{"dots"} for dot plots
+#'            \item \code{"h"}, \code{"hist"}, \code{"histogram"} for grouped histograms
+#'            \item \code{"box"}, \code{"boxplot"}, \code{"boxplots"} for box plots
+#'            \item \code{"v"}, \code{"violin"} for violin box plots
+#'            }
 #' @param dotSize Size of dots. Applies only when \code{type} is set to \code{"dots"}.
 #' @param hideLegend Indicates whether legend (guide) should be shown or not.
 #' @param maxYlim Indicates how to calculate the maximum limit of the y-axis.
@@ -43,7 +49,8 @@ if(getRversion() >= "2.15.1") utils::globalVariables(c("ypos", "wb", "ia", "mw",
 #'          depending on the variable.
 #' @param upperYlim Uses a pre-defined upper limit for the y-axis. Overrides the \code{maxYlim} parameter.
 #' @param useFacetGrid \code{TRUE} when bar charts should be plotted as facet grids instead of integrated single
-#'          bar charts. Ideal for larger amount of groups.
+#'          bar charts. Ideal for larger amount of groups. This parameter wraps a single panel into 
+#'          \code{varGrpup} amount of panels, i.e. each group is represented within a new panel.
 #' @param title Title of the diagram, plotted above the whole diagram panel.
 #' @param titleSize The size of the plot title. Default is 1.3.
 #' @param titleColor The color of the plot title. Default is \code{"black"}.
@@ -81,10 +88,12 @@ if(getRversion() >= "2.15.1") utils::globalVariables(c("ypos", "wb", "ia", "mw",
 #' @param barSpace Spacing between bars. Default value is 0.1. If 0 is used, the grouped bars are sticked together and have no space
 #'          in between. Recommended values for this parameter are from 0 to 0.5
 #' @param barColor User defined color for bars.
-#'          If not specified (\code{NULL}), a default red-green-yellow color palette will be used for the bar charts.
-#'          If barColor is \code{"gs"}, a greyscale will be used.
-#'          If barColor is \code{"bw"}, a monochrome white filling will be used.
-#'          If barColor is \code{"brewer"}, use the \code{colorPalette} parameter to specify a palette of the color brewer.
+#'          \itemize{
+#'            \item If not specified (\code{NULL}), a default red-green-yellow color palette will be used for the bar charts.
+#'            \item If barColor is \code{"gs"}, a greyscale will be used.
+#'            \item If barColor is \code{"bw"}, a monochrome white filling will be used.
+#'            \item If barColor is \code{"brewer"}, use the \code{colorPalette} parameter to specify a palette of the color brewer.
+#'          }
 #'          Else specify your own color values as vector (e.g. \code{barColor=c("#f00000", "#00ff00", "#0080ff")}).
 #' @param colorPalette If \code{barColor} is \code{"brewer"}, specify a color palette from the color brewer here. All color brewer 
 #'          palettes supported by ggplot are accepted here.
@@ -106,8 +115,8 @@ if(getRversion() >= "2.15.1") utils::globalVariables(c("ypos", "wb", "ia", "mw",
 #' @param outlineColor The color of the bar outline. Only applies, if \code{barOutline} is set to \code{TRUE}.
 #' @param majorGridColor Specifies the color of the major grid lines of the diagram background.
 #' @param minorGridColor Specifies the color of the minor grid lines of the diagram background.
-#' @param hideGrid.x If \code{TRUE}, the x-axis-gridlines are hidden. Default if \code{FALSE}.
-#' @param hideGrid.y If \code{TRUE}, the y-axis-gridlines are hidden. Default if \code{FALSE}.
+#' @param hideGrid.x If \code{TRUE}, the x-axis-gridlines are hidden. Default is \code{FALSE}.
+#' @param hideGrid.y If \code{TRUE}, the y-axis-gridlines are hidden. Default is \code{FALSE}.
 #' @param showValueLabels Whether counts and percentage values should be plotted to each bar. Default
 #'          is \code{TRUE}.
 #' @param showCountValues If \code{TRUE} (default), count values are be plotted to each bar. If \code{FALSE},
@@ -148,14 +157,18 @@ if(getRversion() >= "2.15.1") utils::globalVariables(c("ypos", "wb", "ia", "mw",
 #' @param autoGroupAt A value indicating at which length of unique values of \code{varCount} the variable
 #'          is automatically grouped into smaller units (see \link{sju.groupVar}). If \code{varCount} has large 
 #'          numbers of unique values, too many bars for the graph have to be plotted. Hence it's recommended 
-#'          to group such variables. Default value is 50, i.e. if \code{varCount} has 50 and more unique values 
+#'          to group such variables. For example, if \code{autoGroupAt} is 50, i.e. if \code{varCount} has 50 and more unique values 
 #'          it will be grouped using \link{sju.groupVar} with \code{groupsize="auto"} parameter. By default, 
 #'          the maximum group count is 30. However, if \code{autoGroupAt} is less than 30, \code{autoGroupAt} 
-#'          groups are built.
-#' @param theme Specifies the diagram's background theme. default (parameter \code{NULL}) is a gray 
-#'          background with white grids. Use \code{"bw"} for a white background with gray grids, \code{"classic"} for
-#'          a classic theme (black border, no grids), \code{"minimal"} for a minimalistic theme (no border,
-#'          gray grids) or \code{"none"} for no borders, grids and ticks.
+#'          groups are built. Default value for \code{autoGroupAt} is \code{NULL}, i.e. auto-grouping is off.
+#' @param theme Specifies the diagram's background theme. Default (parameter \code{NULL}) is a gray 
+#'          background with white grids.
+#'          \itemize{
+#'          \item Use \code{"bw"} for a white background with gray grids
+#'          \item \code{"classic"} for a classic theme (black border, no grids)
+#'          \item \code{"minimal"} for a minimalistic theme (no border,gray grids) or 
+#'          \item \code{"none"} for no borders, grids and ticks.
+#'          }
 #'          The ggplot-object can be returned with \code{returnPlot} set to \code{TRUE} in order to further
 #'          modify the plot's theme.
 #' @param legendPos The position of the legend, if a legend is drawn. Use \code{"bottom"}, \code{"top"}, \code{"left"}
@@ -238,7 +251,7 @@ if(getRversion() >= "2.15.1") utils::globalVariables(c("ypos", "wb", "ia", "mw",
 #'            legendTitle=efc.var['e42dep'],
 #'            legendLabels=efc.val[['e42dep']],
 #'            type="box")
-#'  
+#'            
 #' @import ggplot2
 #' @importFrom plyr ddply
 #' @importFrom MASS loglm
@@ -310,7 +323,7 @@ sjp.grpfrq <- function(varCount,
                        axisTitle.y=NULL,
                        axisTitleColor="black",
                        axisTitleSize=1.3,
-                       autoGroupAt=50,
+                       autoGroupAt=NULL,
                        theme=NULL,
                        legendPos="right",
                        legendSize=1,
@@ -328,8 +341,8 @@ sjp.grpfrq <- function(varCount,
   #---------------------------------------------------
   # check whether variable should be auto-grouped
   #---------------------------------------------------
-  if (length(unique(varCount))>=autoGroupAt) {
-    cat(sprintf("Variable has %i unique values and was grouped...\n", length(unique(varCount))))
+  if (!is.null(autoGroupAt) && length(unique(varCount))>=autoGroupAt) {
+    cat(sprintf("\nVariable has %i unique values and was grouped...\n", length(unique(varCount))))
     agcnt <- ifelse (autoGroupAt<30, autoGroupAt, 30)
     axisLabels.x <- sju.groupVarLabels(varCount, groupsize="auto", autoGroupCount=agcnt)
     varCount <- sju.groupVar(varCount, groupsize="auto", asNumeric=TRUE, autoGroupCount=agcnt)
@@ -1289,7 +1302,7 @@ sjp.grpfrq <- function(varCount,
         theme(panel.border = element_rect(colour=borderColor))
     }
     else {
-      print("Parameter 'borderColor' can only be applied to 'bw' theme.")
+      cat("\nParameter 'borderColor' can only be applied to 'bw' theme.\n")
     }
   }
   if (!is.null(axisColor)) {
@@ -1319,8 +1332,8 @@ sjp.grpfrq <- function(varCount,
     # Here we start when we have a faces grid instead of
     # a grouped bar plot.
     # --------------------------------------------------
-      # set font size for axes.
     baseplot <- baseplot + 
+      # set font size for axes.
       theme(strip.text = element_text(face="bold",size=rel(1.2))) +
       facet_wrap( ~ group)
   }
