@@ -62,10 +62,13 @@ if(getRversion() >= "2.15.1") utils::globalVariables(c("beta", "lower", "upper",
 #' @param modelColors A vector with colors for representing the beta values (i.e. points and error bars)
 #'          of the different fitted models. Thus, the length of this vector must be equal to
 #'          the length of supplied fitted models, so each model is represented by its own color.
-#'          You can use \code{"bw"} or \code{"black"} for only one colouring
-#'          in almost black, \code{"gray"} / \code{"grey"} / \code{"gs"} for a grayscale or \code{"brewer"} for colours
-#'          from the color brewer palette.
-#'          If modelColors is \code{"brewer"}, use the \code{colorPalette} parameter to specify a palette of the color brewer.
+#'          You can use:
+#'          \itemize{
+#'            \item \code{"bw"} or \code{"black"} for only one colouring in almost black
+#'            \item \code{"gray"}, \code{"grey"} or \code{"gs"} for a grayscale
+#'            \item \code{"brewer"} for colours from the color brewer palette.
+#'            }
+#'          If \code{modelColors} is \code{"brewer"}, use the \code{colorPalette} parameter to specify a palette of the color brewer.
 #'          Else specify your own color values as vector (e.g. \code{modelColors=c("#f00000", "#00ff00")}).
 #' @param colorPalette If parameter \code{modelColors} is \code{brewer}, specify a color palette from the color brewer here.
 #'          All color brewer palettes supported by ggplot are accepted here.
@@ -92,10 +95,14 @@ if(getRversion() >= "2.15.1") utils::globalVariables(c("beta", "lower", "upper",
 #' @param minorGridColor Specifies the color of the minor grid lines of the diagram background.
 #' @param hideGrid.x If \code{TRUE}, the x-axis-gridlines are hidden. Default if \code{FALSE}.
 #' @param hideGrid.y If \code{TRUE}, the y-axis-gridlines are hidden. Default if \code{FALSE}.
-#' @param theme specifies The diagram's background theme. Default (parameter \code{NULL}) is a gray 
-#'          background with white grids. Use \code{"bw"} for a white background with gray grids, \code{"classic"} for
-#'          a classic theme (black border, no grids), \code{"minimal"} for a minimalistic theme (no border,
-#'          gray grids) or \code{"none"} for no borders, grids and ticks.
+#' @param theme Specifies the diagram's background theme. Default (parameter \code{NULL}) is a gray 
+#'          background with white grids.
+#'          \itemize{
+#'          \item Use \code{"bw"} for a white background with gray grids
+#'          \item \code{"classic"} for a classic theme (black border, no grids)
+#'          \item \code{"minimal"} for a minimalistic theme (no border,gray grids) or 
+#'          \item \code{"none"} for no borders, grids and ticks.
+#'          }
 #'          The ggplot-object can be returned with \code{returnPlot} set to \code{TRUE} in order to further
 #'          modify the plot's theme.
 #' @param flipCoordinates If \code{TRUE} (default), predictors are plotted on the left y-axis and estimate
@@ -562,7 +569,7 @@ sjp.lmm <- function(...,
         theme(panel.border = element_rect(colour=borderColor))
     }
     else {
-      print("Parameter 'borderColor' can only be applied to 'bw' theme.")
+      cat("\nParameter 'borderColor' can only be applied to 'bw' theme.\n")
     }
   }
   if (!is.null(axisColor)) {
